use std::pin::Pin;

use crate::future::Future;
use crate::stream::{Extend, IntoStream, Stream};

impl<T> Extend<T> for Vec<T> {
    fn extend_with_stream<'a, S: IntoStream<Item = T> + 'a>(
        &'a mut self,
        stream: S,
    ) -> Pin<Box<dyn Future<Output = ()> + 'a>> {
        let stream = stream.into_stream();
        Box::pin(async move {
            pin_utils::pin_mut!(stream);
            while let Some(item) = stream.next().await {
                self.push(item);
            }
        })
    }
}
